@@ -2,9 +2,8 @@
 
    This file is part of the lzop file compressor.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2003 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    lzop and the LZO library are free software; you can redistribute them
    and/or modify them under the terms of the GNU General Public License as
@@ -22,7 +21,8 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
+   http://www.oberhumer.com/opensource/lzop/
  */
 
 
@@ -39,11 +39,11 @@
 #undef USE_FRAMES
 
 
-#if 1 && defined(LZOP_HAVE_CONFIG_H)
+#if 1 && defined(LZOP_ENABLE_ANSI) && !defined(DOSISH)
 #  define USE_ANSI
 #endif
 
-#if 1 && defined(__linux__)
+#if 1 && defined(__linux__) && defined(LZOP_ENABLE_LINUX_CONSOLE)
 #  define USE_SCREEN
 #  define USE_SCREEN_VCSA
 #  if !defined(HAVE_LINUX_KD_H)
@@ -61,7 +61,7 @@
 #  define USE_SCREEN_CURSES
 #endif
 
-#if 1 && defined(__DJGPP__)
+#if 0 && defined(__DJGPP__)
 #  define USE_SCREEN
 #endif
 
@@ -103,12 +103,12 @@
 **************************************************************************/
 
 enum {
-	CON_INIT,
-	CON_NONE,
-	CON_ANSI_MONO,
-	CON_ANSI_COLOR,
-	CON_SCREEN,
-	CON_UNUSED
+    CON_INIT,
+    CON_NONE,
+    CON_ANSI_MONO,
+    CON_ANSI_COLOR,
+    CON_SCREEN,
+    CON_UNUSED
 };
 
 
@@ -116,17 +116,17 @@ enum {
 
 typedef struct
 {
-	int (*init)(FILE *f, int, int);
-	int (*set_fg)(FILE *f, int fg);
-	void (*print0)(FILE *f, const char *s);
-	lzo_bool (*intro)(FILE *f);
+    int (*init)(FILE *f, int, int);
+    int (*set_fg)(FILE *f, int fg);
+    void (*print0)(FILE *f, const char *s);
+    lzo_bool (*intro)(FILE *f);
 }
 console_t;
 
 
 #if defined(__GNUC__)
 void con_fprintf(FILE *f, const char *format, ...)
-		__attribute__((format(printf,2,3)));
+        __attribute__((format(printf,2,3)));
 #else
 void con_fprintf(FILE *f, const char *format, ...);
 #endif
@@ -179,19 +179,19 @@ extern console_t console_ansi_color;
 extern console_t console_screen;
 
 
-#define con_fg(f,x)		con->set_fg(f,x)
-#define con_intro(f)	con->intro(f)
+#define con_fg(f,x)     con->set_fg(f,x)
+#define con_intro(f)    con->intro(f)
 
 #else
 
-#define con_fg(f,x)		0
-#define con_fprintf		fprintf
-#define con_intro(f)	0
+#define con_fg(f,x)     0
+#define con_fprintf     fprintf
+#define con_intro(f)    0
 
 #endif /* USE_CONSOLE */
 
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
