@@ -2,9 +2,8 @@
 
    This file is part of the lzop file compressor.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2003 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    lzop and the LZO library are free software; you can redistribute them
    and/or modify them under the terms of the GNU General Public License as
@@ -22,14 +21,17 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
+   http://www.oberhumer.com/opensource/lzop/
  */
 
 
-#include "lzop.h"
+#include "conf.h"
 
 #if defined(USE_SCREEN)
 
+#define this local_this
+
 #include "screen.h"
 
 
@@ -39,47 +41,47 @@
 
 void sobject_destroy(screen_t *this)
 {
-	if (!this)
-		return;
-	if (this->data)
-	{
-		if (this->finalize)
-			this->finalize(this);
-		free(this->data);
-		this->data = NULL;
-	}
-	free(this);
+    if (!this)
+        return;
+    if (this->data)
+    {
+        if (this->finalize)
+            this->finalize(this);
+        free(this->data);
+        this->data = NULL;
+    }
+    free(this);
 }
 
 
 screen_t *sobject_construct(const screen_t *c, size_t data_size)
 {
-	screen_t *this;
+    screen_t *this;
 
-	/* allocate object */
-	this = (screen_t *) malloc(sizeof(*this));
-	if (!this)
-		return NULL;
+    /* allocate object */
+    this = (screen_t *) malloc(sizeof(*this));
+    if (!this)
+        return NULL;
 
-	/* copy function table */
-	*this = *c;
+    /* copy function table */
+    *this = *c;
 
-	/* initialize instance variables */
-	this->data = (struct screen_data_t *) malloc(data_size);
-	if (!this->data)
-	{
-		free(this);
-		return NULL;
-	}
-	memset(this->data,0,data_size);
+    /* initialize instance variables */
+    this->data = (struct screen_data_t *) malloc(data_size);
+    if (!this->data)
+    {
+        free(this);
+        return NULL;
+    }
+    memset(this->data,0,data_size);
 
-	return this;
+    return this;
 }
 
 #endif /* defined(USE_SCREEN) */
 
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
